==> haskell-vault-0.3.1.5-154-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-985OGnVccLz2gg2URHoFYL
key:                  vault-0.3.1.5-985OGnVccLz2gg2URHoFYL
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  d7dd70038a0fc468048cd425e5599338
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.0.2/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-985OGnVccLz2gg2URHoFYL
depends:
    base-4.15.1.0 containers-0.6.4.1
    hashable-1.4.3.0-ESEjVh9IF6l3kXlrvIyche
    unordered-containers-0.2.19.1-J4eg8YowQRtEC3N7B7zfuy

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.5-157-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-Iopt7WFgeJ3Cgj0WyXFJTB
key:                  vault-0.3.1.5-Iopt7WFgeJ3Cgj0WyXFJTB
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  0a4e2bbdaa2d73dd421743210fae8e90
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.0.2/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-Iopt7WFgeJ3Cgj0WyXFJTB
depends:
    base-4.15.1.0 containers-0.6.4.1
    hashable-1.4.3.0-HJgArJTlHGmAXC3Ze6Bl1H
    unordered-containers-0.2.19.1-ChULPaPHhwJ2dhnjSGpBLT

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
